# This is demo script to continuousely download 4 articles
import fqterm
import sys, time

# f=open("/home/dp2/test.txt","w")
f = open("c:\\test.txt", "w")

lp=long(sys.argv[0])

for i in range(4):
	fqterm.sendString(lp,"r")
	time.sleep(1)
	f.write(fqterm.getArticle(lp, 100)[0])
	time.sleep(1)
	fqterm.sendString(lp,"q")
	time.sleep(1)
	fqterm.sendString(lp,"j")
	time.sleep(1)
f.close()



# coding=UTF-8
# various tools

# Left Arrow <--
def sendLeft(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[C")
# Left Arrow -->
def sendRight(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[D")
# Up Arrow  
def sendUp(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[A")
# Down Arrow  
def sendDown(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[B")
# Page Up
def sendPageUp(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[5")
# Page Down
def sendPageDown(fqterm,lp):
	fqterm.sendParsedString(lp,"^[[6")
# Enter 
def sendDown(fqterm,lp):
	fqterm.sendParsedString(lp,"^M")

# Page State
# Firebird BBS only
def getPageState(fqterm,lp):
	pageState="unknown"
	lastline=fqterm.getText(lp,fqterm.rows(lp)-1)
	if(lastline.find("阅读文章")!=-1 or
		lastline.find("阅读精华区")!=-1 or
		lastline.find("下面还有")!=-1 or
		lastline.find("回信")!=-1):
		pageState="reading"
	elif(lastline.find("时间")!=-1 and
		lastline.find("使用者")!=-1):
		pageState="list"

	return pageState

# analyze article list	
# return a dictionary
# {"num":xxx,"sign":"","id":"","date":"","title":""}
def getListInfo(text):
	lst=text.split()
	info["num"]=long(lst[0])
	info["sign"]=lst[1]
	info["id"]=lst[2]
	info["date"]=lst[3]+lst[4]
	info["title"]=lst[5]
	return info

# get the current user ID
# only for FireBird BBS
def getCurrentID(fqterm,lp):
	text = fqterm.getText(lp,fqterm.rows(lp)-1)
	if(text.find("使用者")==-1):
		return
	lst = string.split(text,"]")
	text = lst[2]
	lst = string.split(text,"[")
	return lst[1]





# coding=UTF-8
"""
This information is used to track the changes following this format
	dd/mm/yy	Author
		* changes
		* ...

	10/09/04	kingson
		* merge code for ytht.net preview by cppgx
	08/09/04	kingson
		* add this changelog information
"""
import fqterm, string
import re, urllib

"""
get url from ytht
"""

def previewYTHT(lp):
	URL=fqterm.getURL(lp)
	if(URL=='' or URL==None):
		return
	if re.search('http://ytht.net/Ytht.Net' \
		'(\S+)/con\?B=(\d+)&F=M\.(\d+)\.A', URL) != None:
		# ytht artical URL
		print 'Analizing ytht artical URL'
		f_con = urllib.urlopen(URL)
		con = f_con.read()
		f_con.close()
		m_con = re.search('src=\"http://162.105.31.(\d+)(/|:(\d+)/)' \
			'Ytht.Net/boards/(\d+)/M\.(\d+)\.A\+\d+\"', con)
		if m_con != None:
			URL1 = con[(m_con.start() + 5):(m_con.end() - 1)]
			print 'URL1 = %s' % URL1
			f_con1 = urllib.urlopen(URL1)
			con1_lines = f_con1.readlines()
			f_con1.close()
			x = range(0, len(con1_lines))
			for i in x:
				m_con1 = re.search('<a href=\'http://162.105.31.(\d+)' \
				'(/|:(\d+)/)Ytht.Net/attach/bbscon/(\S+)\?B=(\d+)&amp;' \
				'F=M\.(\d+)\.A&amp;attachpos=(\d+)&amp;attachname=/(\S+)\'', \
				con1_lines[i])
				if m_con1 != None:
					URL2 = con1_lines[i][(m_con1.start() + 9): \
					(m_con1.end() - 1)].replace('&amp;', '&')
					print 'URL2 = %s' % URL2
					fqterm.previewImage(lp, URL2)

"""
this is called when beep received
"""
def onBell(lp):
	pass

"""
this is called when ready to autoreply
"""
def autoReply(lp):
	reply = "I am the auto replier, please wait..."
	reply_key = fqterm.getReplyKey(lp)
	if(reply_key==''):
		fqterm.sendParsedString(lp,"^Z")
	else:
		fqterm.sendParsedString(lp,reply_key)
	fqterm.sendString(lp,reply)
	fqterm.sendParsedString(lp,"^M")

"""
this is called when no activity after certain seconds, 
which is set in AddressBook dialog
"""
def antiIdle(lp):
	fqterm.sendParsedString(lp,"^@")
	print "antiIdle"

"""
whenever there is a mouse event
type	0-press  1-release  2-move  3-double click 4-wheel
state	0x01-left  0x02-right  0x04-middle 0x08-alt  0x10-control 0x20-shift
cx/cy	cursor position x/y in character
"""
def mouseEvent(lp, type, state, x, y, delta):
	# left click + control to preview image
	if type==0 and state==0x11:
		previewYTHT(lp)

"""
whenever there is a key event
type	0-press 1-release
state	0x08-alt  0x10-control 0x20-shift
key		refer to Qt/Doc
"""
def keyEvent(lp, type, state, key):
	pass

"""
whenever there is data from server after decoding
and displaying
"""
def dataEvent(lp):
	pass



# coding=UTF-8
"""
download the directory

	13/09/04	kingson
	* add this changelog
	
Notes:
	1. make sure the path is empty, otherwise mkdir complain and stoped
	2. the time for sleep() varies dependent on sites
	3. tested for FireBird BBS only
Bugs:
	1.
TODO:
	1. add some GUI for control, e.g. stop, pause, resume,  inside script
	2. make it robust
"""

import fqterm
import sys,os,string,time,re

# the pointer to fqtermWindow object
lp=long(sys.argv[0])

wait_time = 2.0

def txt2html(txt):
	txt=string.replace(txt,"\n","\n<br>")
	return string.replace(txt," ","&nbsp;")
	
def upper_dir(path):
	if(sys.platform=="win32"):	# '\' for win32
		i=path.rfind("\\",0,-1)
	else:
		i=path.rfind("/",0,-1)	# '/' for *nix
	return path[:i+1]

def lower_dir(path, subdir):
	if(sys.platform=="win32"):	# '\' for win32
		return path+subdir+"\\"
	else:
		return path+subdir+"/"	# '/' for *nix

def write_html_header(hfile, num):
	hfile.write("""<html><head>
		<meta http-equiv="Content-Language" content="zh-cn">
		<meta http-equiv="Content-Type" content="text/html; charset=gb2312">
		<title>FQTerm Article Downloader</title>
		</head>""")
	hfile.write("<body>")
	hfile.write("<p><b><h1>FQTerm Article Downloader</h1></b></p>")
	txt="""<p><p align=center><a href=%d.html>Prevoius</a>     
		<a href=index.html>Index</a>      
		<a href=%d.html>Next</a></p align=center></p>""" % (num-1,num+1)
	hfile.write(txt)
	hfile.write("<hr><p></p>\n")

def write_html_ender(hfile,num):
	hfile.write("<hr><p></p>")
	txt="""<p><p align=center><a href=%d.html>Prevoius</a>     
		<a href=index.html>Index</a>      
		<a href=%d.html>Next</a></p align=center></p>""" % (num-1,num+1)
	hfile.write(txt)
	hfile.write("<p><b>FQTerm --- BBS client based on Qt library</b><p>")
	hfile.write("""<p><a href=http://code.google.com/p/fqterm>
				http://code.google.com/p/fqterm</a><p>""")
	hfile.write("</body>")
	hfile.write("</html>")

def write_index_header(hfile):
	hfile.write("""<html><head>
		<meta http-equiv="Content-Language" content="zh-cn">
		<meta http-equiv="Content-Type" content="text/html; charset=gb2312">
		<title>FQTerm Article Downloader</title>
		</head>""")
	hfile.write("<p><b><h1>FQTerm Article Downloader</h1></b></p>")
	hfile.write("""<p><p align=center>
				<a href=\"../index.html\">Up</a>
				</p align=center</p>""")
	hfile.write("<hr><p></p>\n")

def write_index_ender(hfile):
	hfile.write("<hr><p></p>")
	hfile.write("""<p><p align=center>
				<a href=\"../index.html\">Up</a>
				</p align=center</p>""")
	hfile.write("<p><b>FQTerm --- BBS client based on Qt library</b><p>")
	hfile.write("""<p><a href=http://code.google.com/p/fqterm>
				http://code.google.com/p/fqterm</a><p>""")
	hfile.write("</body>")
	hfile.write("</html>")

def get_list_num(str_line):
	# get the number
	matchobj = re.search("[0-9]+",str_line)
	if(matchobj==None):
		# wrong format
		return None
	else:
	   return str_line[matchobj.start():matchobj.end()]

def get_list_categary(str_line):
	# get the categary
	matchobj = re.search("\[[^0-9]{6}\]",str_line)
	if(matchobj==None):
		# wrong format
		return None
	else:
		return str_line[matchobj.start():matchobj.end()]

def get_list_title(str_line):
	matchobj = re.search("\[[^0-9]{6}\]",str_line)
	if(matchobj==None):
		# wrong format
		return None
	else:
		# get the title	
		return  str_line[matchobj.end()+1:]

def down_folder():
	global path
	first_num = -1
	while(1):
		line=fqterm.caretY(lp) 
		str_line=fqterm.getText(lp,line)
	
		article_num = get_list_num(str_line)
		if (first_num == -1):
			first_num = article_num
		if(article_num==None):
			print "Wrong format list"
			# end the index.html
			f=open(path+"index.html","a+")
			write_index_ender(f)
			f.close()
			# wrong formated list, leave out
			print "leave %s" % path
			fqterm.sendString(lp,'q')
			path=upper_dir(path)
			time.sleep(wait_time)
			return	

		article_categary = get_list_categary(str_line)
		article_title = get_list_title(str_line)	

		# download if its file
		if article_categary == '[文件]':
			# log in index.html
			f=open(path+"index.html","a+")
			f.write("<p><a href="+article_num+".html>")
			f.write("[文件] "+article_title+"</a></p>\n")
			f.close()
			# downlaod and save article 
			f=open(path+article_num+".html","w")
			fqterm.sendString(lp,'r')
			time.sleep(wait_time)
			write_html_header(f,int(article_num))
			f.write(txt2html(fqterm.getArticle(lp, 100)[0]))
			f.write("\n")
			write_html_ender(f,int(article_num))
			f.close()
			time.sleep(wait_time)
			fqterm.sendString(lp,"q")
			time.sleep(wait_time)
		# recursive callback if its directory
		elif article_categary == '[目录]':
			# log in index.html
			f=open(path+"index.html","a+")
			f.write("<p><a href="+article_num+"/index.html>")
			f.write("[目录] "+article_title+"</a></p>\n")
			f.close()
			# make dir and enter
			path=lower_dir(path,article_num)
			os.mkdir(path)
			print "enter %s" % path
			# create index.html and write the header
			f=open(path+"index.html","w")
			write_index_header(f)
			f.close()
			# recursive call
			fqterm.sendString(lp,'r')
			time.sleep(wait_time)
			# increase delay when condition not met
			down_folder()
		else:
			print "Unrecognized Categary"
			# end the index.html
			f=open(path+"index.html","a+")
			write_index_ender(f)
			f.close()
			# wrong formated list, leave out
			print "leave %s" % path
			fqterm.sendString(lp,'q')
			path=upper_dir(path)
			time.sleep(wait_time)
			return	
		str_next=fqterm.getText(lp,line+1)
		# move cursor down and get the num
		fqterm.sendString(lp,'j')
		time.sleep(wait_time)
		str_next=fqterm.getText(lp,fqterm.caretY(lp))
		article_num_next = get_list_num(str_next)
		if(article_num_next==None):
			print "Wrong format list"
			# end the index.html
			f=open(path+"index.html","a+")
			write_index_ender(f)
			f.close()
			# wrong formated list, leave out
			print "leave %s" % path
			fqterm.sendString(lp,'q')
			path=upper_dir(path)
			time.sleep(wait_time)
			return	
		# exit current dir when the number of the next one equals or small then last
		# this may cause problem when the server is extra slow 
		if(int(article_num_next) <= int(article_num)):
			#print "leaving, because cur: %s < pre: %s" % (article_num_next , article_num)
			if(path!=path_dir):
				# end the index.html
				f=open(path+"index.html","a+")
				write_index_ender(f)
				f.close()
				# leave out
				print "leave %s" % path
				fqterm.sendString(lp,'q')
				path=upper_dir(path)
				time.sleep(wait_time)
			return

# NOTE: make sure path ended with '/'(*nix) or '\\'(windowz)
#path_dir=path="e:\\temp\\test\\"
path_dir=path="/home/dp2/temp/test/"

# try to save all to home dir
# path_dir=path=os.environ['HOME']+"/.fqterm/downloads/"+time.ctime()+"/"
os.makedirs(path)

# enter
fqterm.sendString(lp,'x') 
time.sleep(wait_time)
# create index.html and write the header
f=open(path+"index.html","w")
write_index_header(f)
f.close()
down_folder()
# end the index.html
f=open(path+"index.html","a+")
write_index_ender(f)
f.close()
# exit
fqterm.sendString(lp,'q')




# send current article to one assigned email address
# 1. need CJK codec 
import smtplib
from email.Header import Header
from email.Message import Message
import fqterm,sys,string

lp=long(sys.argv[0])
article=fqterm.getArticle(lp, 100)[0]

from_addr = "mime@email.com"
to_addr="yours@email.com"

subject = article.split("\n")
subject = subject[1]
subject = subject[7:]

mess = Message()
h = Header(subject,'GB2312')
mess['Subject']=h

msg = ("Content-Type: text/plain; charset= GB2312\r\n"
	"From: %s\r\nTo: %s\r\n%s\r\n\r\n"
	% (from_addr,to_addr, mess.as_string()))
msg = msg + article

smtp_host = "smtp.email.com"
server = smtplib.SMTP(smtp_host)
server.set_debuglevel(1)
#maybe your smtp need auth
#server.login(usr,pwd)
server.sendmail(from_addr,to_addr,msg)
server.quit()



# coding=UTF-8
# 连续发文

import fqterm
import sys, string, random

sessionID=long(sys.argv[0])
#print "sessionID is %s"%ID

random.seed()
for j in range(13):
	i=random.random()*100000
	print i
	title='%f只青蛙%f张嘴'%(i,i)
	content='%f只眼睛%f条腿'%(2*i,4*i)
	#data=['^p', title, '\n', '\n', content, '^w','\n']
	fqterm.sendParsedString(sessionID, r'^p%s\n\n%s^w\n'%(title, content) )
	#for item in data:
	#	SendParsedString(ID, item)
	#	if dataEvents.has_key(ID):
	#		dataEvents[ID].wait()



# coding=UTF-8

# 从硬盘文件连续发文
# for fqterm: we need to add some status check.

import fqterm
import tools
import sys, string, random, glob, os, time

ID=long(sys.argv[0])
#print "sessionID is %s"%ID

random.seed()
os.chdir(r'/home/dp2/') #主目录
filenames = glob.glob(r'*.txt') #过滤条件
#filenames.extend(  )
for n in filenames:
	print n
	if len(n)>=5 and n[0:5]=='album': #特例
		continue
	#if n[-4:len(n)]!='.txt':
	#	continue
	f=file(n, 'r')
	title=f.readline()
	title=title.strip()
	while title and title.strip()=='':
		title=f.readline()
		title=title.strip()
	if not title:
		continue
	content=f.read()
	
	if not title or not content:
		continue

	data=['\x10', title, '\n', '\n', content, '\x17']

	for item in data:
		fqterm.sendString(ID, item)
		print item
		#if dataEvents.has_key(ID):
			#dataEvents[ID].wait()
	fqterm.sendString(ID, '\n')
	#WaitFor(ID, SST_LIST)

	interval=random.random()*7+3
	#print interval
	time.sleep(interval)
